==> Bundle-Git-LongList1-0.01.tar.gz: Bundle-Git-LongList1-0.01/lib/Bundle/Git/LongList1.pm <==
package Bundle::Git::LongList1;

use 5.005;
our $VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::Git::LongList1 - 
  Perl extension for installing all git modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Git::LongList1'

=head1 DESCRIPTION

Bundle::Git::LongList1 is the first part of three parts.
  It's based on the long list as given by 01modules.index.
 
=head1 CONTENTS

Exporter

Carp

XSLoader

Test

parent

Encode

IO::Handle

File::Spec

File::Path

Time::HiRes

Test::Harness

Test::More

constant

Text::Wrap

Pod::Escapes

Pod::Simple

Pod::Man

Data::Dumper

ExtUtils::MakeMaker

threads::shared

Scalar::Util

Test::Tester

Devel::StackTrace

Test::NoWarnings

Test::Deep

Data::Dump

lib

version

File::Temp

Digest::base

Digest::MD5

Text::Balanced

Parse::RecDescent

Filter::Util::Call

Inline::Files

Inline::C

Capture::Tiny

Test::FailWarnings

Text::ParseWords

CPAN::Meta::YAML

ExtUtils::ParseXS

Pod::Usage

Getopt::Long

Text::Abbrev

Parse::CPAN::Meta

Locale::Maketext

Locale::Maketext::Simple

Locale::Maketext::Lexicon

Module::Metadata

Module::Load

Module::Load::Conditional

Params::Check

Socket

ExtUtils::CBuilder

ExtUtils::Manifest

Perl::OSType

CPAN::Meta::Requirements

CPAN::Meta

ExtUtils::Install

Module::Build

Sub::Uplevel

base

Test::Exception

Data::Validate::Type

Test::Type

IO::Pty

Test::CPAN::Meta

Perl::MinimumVersion

Test::MinimumVersion

IPC::Run

System::Command

Git::Repository

Git::Repository::Plugin::Log

JSON::PP

ExtUtils::Config

ExtUtils::InstallPaths

ExtUtils::Helpers

TAP::Harness::Env

Module::Build::Tiny

Sub::Install

Params::Util

Data::OptList

List::MoreUtils

Module::Runtime

Sub::Name

if 

Try::Tiny

Test::Fatal

Dist::CheckConflicts

Module::Implementation

Package::Stash

Test::Requires

Class::Load

Perl6::Slurp

Git::Repository::Plugin::Blame

Term::ReadLine::Gnu

Term::ReadLine

Memoize

Text::Reform

Text::Autoformat

HTML::Entities

Perl::Tidy

Term::ANSIColor

Git::Deploy

URI::Escape

WWW::RobotRules

Time::Local

HTTP::Date

HTTP::Headers::Util

HTTP::Cookies

AutoLoader

Net::HTTP

Log::Agent

LWP::MediaTypes

Storable

HTTP::Daemon

HTML::Tagset

HTTP::Negotiate

File::Listing

IO::HTML

Encode::Locale

MIME::Base64

LWP::UserAgent

YAML::Syck

Net::Ping

Probe::Perl

IPC::Run3

Test::Script

File::Which

File::HomeDir

IO::Zlib

Net::FTP

Term::ReadKey

Text::Glob

Compress::Raw::Bzip2

Socket

IO::String

Archive::Tar

Digest::SHA

HTTP::Tiny

Archive::Zip

YAML

Socket::GetAddrInfo

Socket6

IO::Socket::INET6

IO::Socket::IP

Digest::SHA1

Digest::SHA::PurePerl

Digest::SHA256

Compress::Zlib

Crypt::CBC

Crypt::DES

Crypt::Blowfish

Crypt::RIPEMD160

Tie::EncryptedHash

Class::Loader

Convert::ASCII::Armour

Data::Buffer

Digest::MD2

Math::Pari

Crypt::Random

Crypt::Primes

Crypt::DES_EDE3

Math::BigInt

Math::BigInt::GMP

Class::ErrorHandler

Convert::PEM

Crypt::DSA

Crypt::RSA

Convert::ASN1

Sort::Versions

Crypt::Twofish

Test::Synopsis

Crypt::OpenPGP

GnuPG

Module::Signature

Safe

CPAN

Git::CPAN::Hook


=head1 AUTHOR

Version 0.01 Kevin W. Henwood, <Khen1950fx@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, or, at your option, any later 
version of Perl 5 you may have available.

=cut

==> Bundle-Git-LongList1-0.02.tar.gz: Bundle-Git-LongList1-0.02/lib/Bundle/Git/LongList1.pm <==
package Bundle::Git::LongList1;

use 5.005;
our $VERSION = '0.02';

1;

__END__

=head1 NAME

Bundle::Git::LongList1 - 
  Perl extension for installing all git modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Git::LongList1'

=head1 DESCRIPTION

Bundle::Git::LongList1 is the first part of three parts.
  It's based on the long list as given by 01modules.index.
 
=head1 CONTENTS

Exporter

Carp

Test::Distribution

XSLoader

File::Spec

Test::Harness

Test

lib

IO::Handle

Scalar::Util

Test::Tester

Test::Perl::Critic

Test::EOL

Test::Exception

Test::CPAN::Changes

Test::DistManifest

Test::CPAN::Meta

Test::CPAN::Meta::JSON

Perl::MinimumVersion

Test::MinimumVersion

Test::Mojibake

Test::Pod::LinkCheck

Test::Synopsis

Test::Vars

ExtUtils::CBuilder

Params::Util

Parse::CPAN::Meta

Text::Glob

Number::Compare

File::Find::Rule

File::Find::Rule::Perl

version

constant

Sub::Uplevel

Module::Metadata

Test::Version

parent

Encode

File::Path

Time::HiRes

Test::More

Text::Wrap

Pod::Escapes

Pod::Simple

Term::ANSIColor

File::ShareDir

File::ShareDir::Install

Path::FindDev

IPC::Run3

Probe::Perl

Test::Script

File::Which

File::HomeDir

Module::Runtime

Try::Tiny

Test::Fatal

Role::Tiny

Path::IsDev

Digest::SHA

Digest::base

if

Path::Tiny

Perl::OSType

Path::Class

Class::Inspector

Sub::Exporter

File::ShareDir::ProjectDistDir

Pod::Parser

base

Class::Tiny

Lingua::EN::Inflect

Pod::Spell

Text::Aspell

Lingua::Ispell

Pod::Usage

Getopt::Long

Data::Dumper

ExtUtils::MakeMaker

Pod::Man

threads

threads::shared

Test::NoWarnings

Test::Deep

Data::Dump

Test::Spelling

Test::Pod

Pod::Coverage

Pod::Coverage::TrustPod

Test::Pod::Coverage

Test::Portability::Files

File::Temp

Devel::StackTrace

MIME::Base64

Digest::MD5

SelfLoader

Text::Balanced

File::Slurp::Tiny

Tree::DAG_Node

Test::Warn

Parse::RecDescent

Sub::Exporter::Progressive

Variable::Magic

Sub:::Name

Module::Implementation

B::Hooks::EndOfScope

Test::Requires

Package::Stash

namespace::clean

List::MoreUtils

Dist::CheckConflicts

ExtUtils::Config

ExtUtils::InstallPaths

ExtUtils::ParseXS

Text::ParseWords

Module::Load

ExtUtils::Helpers

ExtUtils::Install

TAP::Harness::Env

CPAN::Meta::Requirements

Module::Build::Tiny

Test::Warnings

IO::Capture

Set::Scalar

Pod::Strip

Module::Pluggable

Algorithm::Diff

Text::Diff

Class::Accessor

Class::Accessor::Fast

Array::Diff

Text::Template

MRO::Compat

Sub::Install

Data::OptList

Capture::Tiny

Test::FailWarnings

Data::Section

Software::License

File::Find::Rule::VCS

Mo::default

YAML

Compress::Raw::Bzip2

Compress::Raw::Zlib

Compress::Zlib

IO::Zlib

Archive::Tar

ExtUtils::Manifest

Test::UseAllModules

Time::Local

Filter::Util::Call

Archive::Zip

Archive::Any::Lite

CPAN::DistnameInfo

CPAN::Meta::YAML

IO::String

Module::CPANTS::Analyse

Test::Kwalitee

Inline::Files

Inline::C

Text::Abbrev

Locale::Maketext

Locale::Maketext::Simple

Locale::Maketext::Lexicon

Module::CoreList

Params::Check

Module::Load::Conditional

ExtUtils::Constant

Socket

JSON::PP

CPAN::Meta

Module::Build

Data::Validate::Type

Test::Type

IO::Pty

IPC::Run

System::Command

Git::Repository

Git::Repository::Plugin::Log

Dist::CheckConflicts

Class::Load::XS

Class::Load

Sub::Name

Perl6::Slurp

Git::Repository::Plugin::Blame

Term::ReadLine::Gnu

Term::ReadLine

Memoize

Text::Reform

Text::Autoformat

HTML::Entities

Perl::Tidy

Git::Deploy

URI::Escape

WWW::RobotRules

HTTP::Date

HTTP::Headers::Util

HTTP::Cookies

AutoLoader

Net::HTTP

Log::Agent

LWP::MediaTypes

Storable

Encode::Locale

HTTP::Daemon

HTML::Tagset

HTTP::Negotiate

File::Listing

IO::HTML

LWP::UserAgent

YAML::Syck

Net::Ping

IO::Zlib

Net::FTP

Term::ReadKey

IO::Socket::IP

HTTP::Tiny

IPC::Cmd

ExtUtils::CChecker

Module::Build::Compat

Socket::GetAddrInfo

Socket6

IO::Socket::INET6

Digest::SHA1

Digest::SHA::PurePerl

Digest::SHA256

Crypt::CBC

Crypt::DES

Crypt::Blowfish

Crypt::RIPEMD160

Tie::EncryptedHash

Class::Loader

Convert::ASCII::Armour

Data::Buffer

Digest::MD2

Term::Gnuplot

Math::Pari

Crypt::Random

Crypt::Primes

Crypt::DES_EDE3

Math::BigInt

Math::BigInt::GMP

Class::ErrorHandler

Convert::ASN1

Convert::PEM

Crypt::DSA

Crypt::RSA

Sort::Versions

Crypt::Twofish

Crypt::Rijndael

Crypt::CAST5_PP

Crypt::RIPEMD160

Crypt::IDEA

GnuPG

Module::Signature

Safe

Math::BigInt::Pari

Crypt::OpenPGP

File::pushd

Error

JSON

Mozilla::CA

Net::SSLeay

IO::Socket::SSL

LWP::Protocol::https

Crypt::SSLeay

REST::Client

Test::use::ok

Hash::Util::FieldHash::Compat

Devel::PPPort

Scope::Guard

Data::Util

Net::Netrc

HTML::TreeBuilder

Gerrit::REST

File::Remove

Git::Hooks

Git::CPAN::Hook

=head1 AUTHOR

Version 0.02 Kevin W. Henwood, <Khen1950fx@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, or, at your option, any later 
version of Perl 5 you may have available.

=cut
